@@ -3,11 +3,13 @@ import sys
 
 import pytest
 
-from aiohttp.pytest_plugin import LOOP_FACTORIES
-
 
 pytest_plugins = 'pytester'
 
+CONFTEST = '''
+pytest_plugins = 'aiohttp.pytest_plugin'
+'''
+
 
 def test_aiohttp_plugin(testdir):
     testdir.makepyfile("""\
@@ -17,10 +19,6 @@ from unittest import mock
 
 from aiohttp import web
 
-
-pytest_plugins = 'aiohttp.pytest_plugin'
-
-
 @asyncio.coroutine
 def hello(request):
     return web.Response(body=b'Hello, world')
@@ -72,7 +70,7 @@ def test_hello_fails(test_client):
 
 @asyncio.coroutine
 def test_hello_with_fake_loop(test_client):
-    with pytest.raises(AssertionError):
+    with pytest.raises(RuntimeError):
         fake_loop = mock.Mock()
         yield from test_client(web.Application(loop=fake_loop))
 
@@ -153,11 +151,9 @@ def test_client_failed_to_create(test_client):
         yield from test_client(make_app)
 
 """)
-    testdir.runpytest('-p', 'no:sugar')
-
-    # i dont know how to fix this
-    # result = testdir.runpytest('-p', 'no:sugar')
-    # result.assert_outcomes(passed=11, failed=1)
+    testdir.makeconftest(CONFTEST)
+    result = testdir.runpytest('-p', 'no:sugar', '--loop=pyloop')
+    result.assert_outcomes(passed=11, failed=1)
 
 
 @pytest.mark.skipif(sys.version_info < (3, 5), reason='old python')
@@ -165,8 +161,6 @@ def test_warning_checks(testdir, capsys):
     testdir.makepyfile("""\
 import asyncio
 
-pytest_plugins = 'aiohttp.pytest_plugin'
-
 async def foobar():
     return 123
 
@@ -177,7 +171,8 @@ async def test_good():
 async def test_bad():
     foobar()
 """)
-    result = testdir.runpytest('-p', 'no:sugar', '-s')
+    testdir.makeconftest(CONFTEST)
+    result = testdir.runpytest('-p', 'no:sugar', '-s', '--loop=pyloop')
     result.assert_outcomes(passed=1, failed=1)
     stdout, _ = capsys.readouterr()
     assert ("test_warning_checks.py:__LINE__:coroutine 'foobar' was "
@@ -192,9 +187,6 @@ import pytest
 from aiohttp import web
 
 
-pytest_plugins = 'aiohttp.pytest_plugin'
-
-
 @asyncio.coroutine
 def hello(request):
     return web.Response(body=b'Hello, world')
@@ -244,9 +236,9 @@ def test_foo_without_loop(foo):
 def test_bar(loop, bar):
     assert bar is test_bar
 """)
-    nb_loops = len(LOOP_FACTORIES)
-    result = testdir.runpytest('-p', 'no:sugar')
-    result.assert_outcomes(passed=3 * nb_loops, error=1)
+    testdir.makeconftest(CONFTEST)
+    result = testdir.runpytest('-p', 'no:sugar', '--loop=pyloop')
+    result.assert_outcomes(passed=3, error=1)
     result.stdout.fnmatch_lines(
         "*Asynchronous fixtures must depend on the 'loop' fixture "
         "or be used in tests depending from it."
@@ -263,8 +255,6 @@ from unittest import mock
 from aiohttp import web
 
 
-pytest_plugins = 'aiohttp.pytest_plugin'
-
 canary = mock.Mock()
 
 
@@ -292,6 +282,6 @@ async def test_hello(cli):
 def test_finalized():
     assert canary.called is True
 """)
-    nb_loops = len(LOOP_FACTORIES)
-    result = testdir.runpytest('-p', 'no:sugar')
-    result.assert_outcomes(passed=1 * nb_loops + 1)
+    testdir.makeconftest(CONFTEST)
+    result = testdir.runpytest('-p', 'no:sugar', '--loop=pyloop')
+    result.assert_outcomes(passed=2)
